@@ -44,7 +44,12 @@ def info(request):
     See: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0024.md#info
     """
 
-    info_data = {"deposit": {}, "withdraw": {}, "fee": {"enabled": True}}
+    info_data = {
+        "deposit": {},
+        "withdraw": {},
+        "fee": {"enabled": True},
+        "features": {"account_creation": True, "claimable_balances": True},
+    }
 
     for asset in Asset.objects.filter(sep24_enabled=True):
         info_data["deposit"][asset.code] = _get_asset_info(asset, "deposit")
