@@ -135,10 +135,14 @@ def get_asset_info(asset: Asset, fields_and_types: Dict) -> Dict:
 
     asset_info = {
         "enabled": True,
-        "min_amount": round(asset.send_min_amount, asset.significant_decimals),
-        "max_amount": round(asset.send_max_amount, asset.significant_decimals),
         **fields_and_types,
     }
+    min_amount = getattr(asset, "send_min_amount")
+    max_amount = getattr(asset, "send_max_amount")
+    if min_amount > Asset._meta.get_field("send_min_amount").default:
+        asset_info["min_amount"] = min_amount
+    if max_amount < Asset._meta.get_field("send_max_amount").default:
+        asset_info["max_amount"] = max_amount
     if asset.send_fee_fixed:
         asset_info["fee_fixed"] = round(
             asset.send_fee_fixed, asset.significant_decimals
