@@ -4,7 +4,7 @@ from unittest.mock import Mock, patch
 
 import pytest
 from polaris.tests.helpers import mock_check_auth_success
-from polaris.models import Transaction
+from polaris.models import Transaction, Asset
 
 
 endpoint = "/sep31/transactions/"
@@ -13,15 +13,19 @@ endpoint = "/sep31/transactions/"
 @pytest.mark.django_db
 @patch("polaris.sep10.utils.check_auth", mock_check_auth_success)
 @patch("polaris.sep31.transactions.registered_sep31_receiver_integration", Mock())
-def test_success_update(client, acc1_usd_deposit_transaction_factory):
-    transaction = acc1_usd_deposit_transaction_factory(
-        protocol=Transaction.PROTOCOL.sep31
+def test_success_update(client):
+    asset = Asset.objects.create(code="USD")
+    transaction = Transaction.objects.create(
+        asset=asset,
+        stellar_account="test source address",
+        protocol=Transaction.PROTOCOL.sep31,
+        kind=Transaction.KIND.send,
+        status=Transaction.STATUS.pending_transaction_info_update,
+        required_info_message="The provided 'bank_account' was invalid.",
+        required_info_updates=json.dumps(
+            {"transaction": {"bank_account": {"description": "a description"}}}
+        ),
     )
-    transaction.status = Transaction.STATUS.pending_transaction_info_update
-    transaction.required_info_updates = json.dumps(
-        {"transaction": {"bank_account": {"description": "a description"}}}
-    )
-    transaction.save()
     response = client.patch(
         endpoint + str(transaction.id),
         {"fields": {"transaction": {"bank_account": "foo"}}},
@@ -37,7 +41,7 @@ def test_success_update(client, acc1_usd_deposit_transaction_factory):
 @pytest.mark.django_db
 @patch("polaris.sep10.utils.check_auth", mock_check_auth_success)
 @patch("polaris.sep31.transactions.registered_sep31_receiver_integration", Mock())
-def test_bad_id(client, acc1_usd_deposit_transaction_factory):
+def test_bad_id(client):
     response = client.patch(
         endpoint + "not an id",
         {"fields": {"transaction": {"bank_account": "foo"}}},
@@ -46,10 +50,26 @@ def test_bad_id(client, acc1_usd_deposit_transaction_factory):
     assert response.status_code == 404
 
 
+@pytest.mark.django_db
+@patch("polaris.sep10.utils.check_auth", mock_check_auth_success)
+@patch("polaris.sep31.transactions.registered_sep31_receiver_integration")
+def test_bad_id(mock_sep31_integration, client):
+    mock_sep31_integration.valid_sending_anchor.return_value = False
+    response = client.patch(
+        endpoint + "test",
+        {"fields": {"transaction": {"bank_account": "foo"}}},
+        content_type="application/json",
+    )
+    assert response.status_code == 403
+    assert mock_sep31_integration.valid_sending_anchor.was_called_once_with(
+        "test source address"
+    )
+
+
 @pytest.mark.django_db
 @patch("polaris.sep10.utils.check_auth", mock_check_auth_success)
 @patch("polaris.sep31.transactions.registered_sep31_receiver_integration", Mock())
-def test_missing_id(client, acc1_usd_deposit_transaction_factory):
+def test_missing_id(client):
     response = client.patch(
         endpoint,
         {"fields": {"transaction": {"bank_account": "foo"}}},
@@ -78,14 +98,19 @@ def test_not_found(client):
 @pytest.mark.django_db
 @patch("polaris.sep10.utils.check_auth", mock_check_auth_success)
 @patch("polaris.sep31.transactions.registered_sep31_receiver_integration", Mock())
-def test_update_not_required(client, acc1_usd_deposit_transaction_factory):
-    transaction = acc1_usd_deposit_transaction_factory(
-        protocol=Transaction.PROTOCOL.sep31
+def test_update_not_required(client):
+    asset = Asset.objects.create(code="USD")
+    transaction = Transaction.objects.create(
+        asset=asset,
+        stellar_account="test source address",
+        protocol=Transaction.PROTOCOL.sep31,
+        kind=Transaction.KIND.send,
+        status=Transaction.STATUS.pending_sender,
+        required_info_message="The provided 'bank_account' was invalid.",
+        required_info_updates=json.dumps(
+            {"transaction": {"bank_account": {"description": "a description"}}}
+        ),
     )
-    transaction.required_info_updates = json.dumps(
-        {"transaction": {"bank_account": {"description": "a description"}}}
-    )
-    transaction.save()
     response = client.patch(
         endpoint + str(transaction.id),
         {"fields": {"transaction": {"bank_account": "foo"}}},
@@ -98,13 +123,17 @@ def test_update_not_required(client, acc1_usd_deposit_transaction_factory):
 @pytest.mark.django_db
 @patch("polaris.sep10.utils.check_auth", mock_check_auth_success)
 @patch("polaris.sep31.transactions.registered_sep31_receiver_integration", Mock())
-def test_bad_info_update_column(client, acc1_usd_deposit_transaction_factory):
-    transaction = acc1_usd_deposit_transaction_factory(
-        protocol=Transaction.PROTOCOL.sep31
+def test_bad_info_update_column(client):
+    asset = Asset.objects.create(code="USD")
+    transaction = Transaction.objects.create(
+        asset=asset,
+        stellar_account="test source address",
+        protocol=Transaction.PROTOCOL.sep31,
+        kind=Transaction.KIND.send,
+        status=Transaction.STATUS.pending_transaction_info_update,
+        required_info_message="The provided 'bank_account' was invalid.",
+        required_info_updates="test",
     )
-    transaction.status = Transaction.STATUS.pending_transaction_info_update
-    transaction.required_info_updates = "test"  # not valid JSON
-    transaction.save()
     response = client.patch(
         endpoint + str(transaction.id),
         {"fields": {"transaction": {"bank_account": "foo"}}},
@@ -116,15 +145,19 @@ def test_bad_info_update_column(client, acc1_usd_deposit_transaction_factory):
 @pytest.mark.django_db
 @patch("polaris.sep10.utils.check_auth", mock_check_auth_success)
 @patch("polaris.sep31.transactions.registered_sep31_receiver_integration", Mock())
-def test_bad_update_body(client, acc1_usd_deposit_transaction_factory):
-    transaction = acc1_usd_deposit_transaction_factory(
-        protocol=Transaction.PROTOCOL.sep31
+def test_bad_update_body(client):
+    asset = Asset.objects.create(code="USD")
+    transaction = Transaction.objects.create(
+        asset=asset,
+        stellar_account="test source address",
+        protocol=Transaction.PROTOCOL.sep31,
+        kind=Transaction.KIND.send,
+        status=Transaction.STATUS.pending_transaction_info_update,
+        required_info_message="The provided 'bank_account' was invalid.",
+        required_info_updates=json.dumps(
+            {"transaction": {"bank_account": {"description": "a description"}}}
+        ),
     )
-    transaction.status = Transaction.STATUS.pending_transaction_info_update
-    transaction.required_info_updates = json.dumps(
-        {"transaction": {"bank_account": {"description": "a description"}}}
-    )
-    transaction.save()
     response = client.patch(
         endpoint + str(transaction.id),
         {"fields": {"transaction": {"not a listed field": True}}},
@@ -137,15 +170,19 @@ def test_bad_update_body(client, acc1_usd_deposit_transaction_factory):
 @pytest.mark.django_db
 @patch("polaris.sep10.utils.check_auth", mock_check_auth_success)
 @patch("polaris.sep31.transactions.registered_sep31_receiver_integration", Mock())
-def test_missing_update_category(client, acc1_usd_deposit_transaction_factory):
-    transaction = acc1_usd_deposit_transaction_factory(
-        protocol=Transaction.PROTOCOL.sep31
+def test_missing_update_category(client):
+    asset = Asset.objects.create(code="USD")
+    transaction = Transaction.objects.create(
+        asset=asset,
+        stellar_account="test source address",
+        protocol=Transaction.PROTOCOL.sep31,
+        kind=Transaction.KIND.send,
+        status=Transaction.STATUS.pending_transaction_info_update,
+        required_info_message="The provided 'bank_account' was invalid.",
+        required_info_updates=json.dumps(
+            {"transaction": {"bank_account": {"description": "a description"}}}
+        ),
     )
-    transaction.status = Transaction.STATUS.pending_transaction_info_update
-    transaction.required_info_updates = json.dumps(
-        {"transaction": {"bank_account": {"description": "a description"}}}
-    )
-    transaction.save()
     response = client.patch(
         endpoint + str(transaction.id),
         {"fields": {"first_name": "test"}},
@@ -158,15 +195,19 @@ def test_missing_update_category(client, acc1_usd_deposit_transaction_factory):
 @pytest.mark.django_db
 @patch("polaris.sep10.utils.check_auth", mock_check_auth_success)
 @patch("polaris.sep31.transactions.registered_sep31_receiver_integration", Mock())
-def test_bad_category_value_type(client, acc1_usd_deposit_transaction_factory):
-    transaction = acc1_usd_deposit_transaction_factory(
-        protocol=Transaction.PROTOCOL.sep31
+def test_bad_category_value_type(client):
+    asset = Asset.objects.create(code="USD")
+    transaction = Transaction.objects.create(
+        asset=asset,
+        stellar_account="test source address",
+        protocol=Transaction.PROTOCOL.sep31,
+        kind=Transaction.KIND.send,
+        status=Transaction.STATUS.pending_transaction_info_update,
+        required_info_message="The provided 'bank_account' was invalid.",
+        required_info_updates=json.dumps(
+            {"transaction": {"bank_account": {"description": "a description"}}}
+        ),
     )
-    transaction.status = Transaction.STATUS.pending_transaction_info_update
-    transaction.required_info_updates = json.dumps(
-        {"transaction": {"bank_account": {"description": "a description"}}}
-    )
-    transaction.save()
     response = client.patch(
         endpoint + str(transaction.id),
         {"fields": {"transaction": "not a dict"}},
@@ -187,15 +228,19 @@ raise_error_integration = Mock(
     "polaris.sep31.transactions.registered_sep31_receiver_integration",
     raise_error_integration,
 )
-def test_user_defined_exception(client, acc1_usd_deposit_transaction_factory):
-    transaction = acc1_usd_deposit_transaction_factory(
-        protocol=Transaction.PROTOCOL.sep31
+def test_user_defined_exception(client):
+    asset = Asset.objects.create(code="USD")
+    transaction = Transaction.objects.create(
+        asset=asset,
+        stellar_account="test source address",
+        protocol=Transaction.PROTOCOL.sep31,
+        kind=Transaction.KIND.send,
+        status=Transaction.STATUS.pending_transaction_info_update,
+        required_info_message="The provided 'bank_account' was invalid.",
+        required_info_updates=json.dumps(
+            {"transaction": {"bank_account": {"description": "a description"}}}
+        ),
     )
-    transaction.status = Transaction.STATUS.pending_transaction_info_update
-    transaction.required_info_updates = json.dumps(
-        {"transaction": {"bank_account": {"description": "a description"}}}
-    )
-    transaction.save()
     response = client.patch(
         endpoint + str(transaction.id),
         {"fields": {"transaction": {"bank_account": "foo"}}},
